import { Component, Fragment } from 'react'
import { ActiveJob, ActiveTransfer, StopButton } from '../styled'
import API from '../utils/API'
import bytesToString from '../utils/bytestring'
import secondsToTimeString from '../utils/timestring'

class Job extends Component {
  constructor(props) {
    super(props)
    this.state = {
      jobid: props.jobid,
      stats: {
        elapsedTime: 0,
        eta: 0,
        bytes: 0,
        totalBytes: 0,
        transferring: props.initialStats?.transferring ?? []
      }
    }
    this.fetchStatsInterval = null
    this.decreaseEtaInterval = null
  }

  componentDidMount() {
    if (this.state.jobid) {
      this.fetchStats()
      this.fetchStatsInterval = setInterval(this.fetchStats, 5000)
    }
    this.decreaseEtaInterval = setInterval(() => {
      this.setState(({ stats }) => ({
        stats: {
          ...stats,
          elapsedTime: stats.elapsedTime + 1,
          eta: Math.max(0, stats.eta - 1),
          transferring: (stats.transferring || []).map(v => ({
            ...v,
            eta: Math.max(0, v.eta - 1)
          }))
        }
      }))
    }, 1000)
  }

  componentWillUnmount() {
    clearInterval(this.fetchStatsInterval)
    clearInterval(this.decreaseEtaInterval)
  }

  fetchStats = () =>
    API.request({ url: '/core/stats', data: { group: `job/${this.state.jobid}` } })
      .then(({ data }) => {
        if (typeof data === 'object') {
          this.setState({
            stats: {
              elapsedTime: data.elapsedTime ?? 0,
              eta:         data.eta ?? 0,
              bytes:       data.bytes ?? 0,
              totalBytes:  data.totalBytes ?? 0,
              transferring: Array.isArray(data.transferring) ? data.transferring : []
            }
          })
        }
      })
      .catch(() => {})

  stopJob = () =>
    API.request({ url: '/job/stop', data: { jobid: this.state.jobid } })
      .then(() => this.props.refreshStats())
      .catch(() => {})

  renderActiveTransfer() {
    const { transferring = [] } = this.state.stats
    if (!transferring.length) return null
    return transferring.map(v => (
      <ActiveTransfer key={v.name}>
        <p>{v.name}</p>
        <p>{bytesToString(v.size, {})}</p>
        <p>{secondsToTimeString(v.eta)}</p>
        <p>{bytesToString(v.speed, { speed: true })}</p>
      </ActiveTransfer>
    ))
  }

  render() {
    const { stats, jobid } = this.state
    return (
      <Fragment>
        <ActiveJob>
          <p>Time elapsed:</p>
          <p>{secondsToTimeString(stats.elapsedTime)}</p>

          <p>Progress:</p>
          <p>
            {bytesToString(stats.bytes, { format: 'GB', fixed: 3 })} /{' '}
            {bytesToString(stats.totalBytes, { format: 'GB', fixed: 3 })} GB
          </p>

          <p>Time left:</p>
          <p>{secondsToTimeString(stats.eta)}</p>

          <p>Progress:</p>
          <p>{((stats.bytes / stats.totalBytes) * 100).toFixed(2)} %</p>

          <p>Speed:</p>
          <p>{bytesToString(stats.speed, { speed: true })}</p>

          {jobid ? <StopButton onClick={this.stopJob}>Cancel</StopButton> : null}
        </ActiveJob>

        {/* Transfers only */}
        {this.renderActiveTransfer()}
      </Fragment>
    )
  }
}

export default Job